==> it%2B%2B3.8.0.tar.gz: it++3.8.0/src/comm/interleave.cpp <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2004 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*!
  \file
  \brief Implementation of Interleaver classes
  \author Pl Frenger

  1.12

  2004/05/07 11:55:37
*/

#include "comm/interleave.h"

namespace itpp {

// #ifdef _MSC_VER
// #pragma warning(disable : 4244)
// #endif

  // ------------------------ Instantiations --------------------------------

  //! Template instantiation of Block_Interleaver
  template class Block_Interleaver<double>;
  //! Template instantiation of Block_Interleaver
  template class Block_Interleaver<short>;
  //! Template instantiation of Block_Interleaver
  template class Block_Interleaver<int>;
  //! Template instantiation of Block_Interleaver
  template class Block_Interleaver<complex<double> >;
  //! Template instantiation of Block_Interleaver
  template class Block_Interleaver<bin>;

  //! Template instantiation of Cross_Interleaver
  template class Cross_Interleaver<double>;
  //! Template instantiation of Cross_Interleaver
  template class Cross_Interleaver<short>;
  //! Template instantiation of Cross_Interleaver
  template class Cross_Interleaver<int>;
  //! Template instantiation of Cross_Interleaver
  template class Cross_Interleaver<complex<double> >;
  //! Template instantiation of Cross_Interleaver
  template class Cross_Interleaver<bin>;

  //! Template instantiation of Sequence_Interleaver
  template class Sequence_Interleaver<double>;
  //! Template instantiation of Sequence_Interleaver
  template class Sequence_Interleaver<short>;
  //! Template instantiation of Sequence_Interleaver
  template class Sequence_Interleaver<int>;
  //! Template instantiation of Sequence_Interleaver
  template class Sequence_Interleaver<complex<double> >;
  //! Template instantiation of Sequence_Interleaver
  template class Sequence_Interleaver<bin>;

// #ifdef _MSC_VER
// #pragma warning(default : 4244)
// #endif

} //namespace itpp

==> it%2B%2B3.8.1.tar.gz: it++3.8.1/src/comm/interleave.cpp <==
/*---------------------------------------------------------------------------*
 *                                   IT++			             *
 *---------------------------------------------------------------------------*
 * Copyright (c) 1995-2005 by Tony Ottosson, Thomas Eriksson, Pl Frenger,   *
 * Tobias Ringstrm, and Jonas Samuelsson.                                   *
 *                                                                           *
 * Permission to use, copy, modify, and distribute this software and its     *
 * documentation under the terms of the GNU General Public License is hereby *
 * granted. No representations are made about the suitability of this        *
 * software for any purpose. It is provided "as is" without expressed or     *
 * implied warranty. See the GNU General Public License for more details.    *
 *---------------------------------------------------------------------------*/

/*!
  \file
  \brief Implementation of Interleaver classes
  \author Pl Frenger

  1.14

  2005/06/13 08:37:20
*/

#include "comm/interleave.h"

namespace itpp {

  // ------------------------ Instantiations --------------------------------

  template class Block_Interleaver<double>;
  template class Block_Interleaver<short>;
  template class Block_Interleaver<int>;
  template class Block_Interleaver<std::complex<double> >;
  template class Block_Interleaver<bin>;

  template class Cross_Interleaver<double>;
  template class Cross_Interleaver<short>;
  template class Cross_Interleaver<int>;
  template class Cross_Interleaver<std::complex<double> >;
  template class Cross_Interleaver<bin>;

  template class Sequence_Interleaver<double>;
  template class Sequence_Interleaver<short>;
  template class Sequence_Interleaver<int>;
  template class Sequence_Interleaver<std::complex<double> >;
  template class Sequence_Interleaver<bin>;

} //namespace itpp
